moya.auth Commands

# Command Index

Commands defined by moya.auth.

Command | Synopsis
--- | ---
`cmd.addperm` | Associate a permission with a user or group
`cmd.adduser` | Add a new user to the database
`cmd.finduser` | Look up a user
`cmd.groupadd` | Add a user to an existing group
`cmd.groupremove` | Remove a user from a group
`cmd.init` | Create default groups/permissions and a superuser
`cmd.listgroups` | List all permission groups
`cmd.listperms` | List permissions
`cmd.listusers` | List users
`cmd.newgroup` | Add a new group
`cmd.newperm` | Create a new permission
`cmd.removeperm` | Add permissions to a user or group
`cmd.test` | tests
`cmd.testusers` | Generate test users